pub struct MessagingAction {
pub name: String,
}Expand description
MessagingAction : A simple object containing the name of the template.
Fields
name: StringImplementations
sourceimpl MessagingAction
impl MessagingAction
sourcepub fn new(name: String) -> MessagingAction
pub fn new(name: String) -> MessagingAction
A simple object containing the name of the template.